##  Deleting a Subscription Role
To delete a subscription role, do the following:
  1. In the administration area, select Subscription Roles.
  2. Select the subscription role you need to delete.
  3. Click Delete.


Deleting subscription roles does not unsubscribe users from fact sheets. Users will continue to be subscribed as responsible, accountable, or observer, even if the specific role they were assigned has been deleted.
